Learn R Programming

wklsr (version 0.2.6)

ncol.wkls_proxy: Get number of columns

Description

Returns the number of columns in the resolved data

Usage

ncol.wkls_proxy(x)

Value

An integer representing the number of columns, or 0L for empty chains

Arguments

x

A wkls_proxy object